OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Aufgaben",
    "Due yesterday" : "Gestern fällig",
    "Due today" : "Heute fällig",
    "Due tomorrow" : "Morgen fällig",
    "Due on" : "Fällig am",
    "Started yesterday" : "Gestern begonnen",
    "Starts today" : "Beginnt heute",
    "Starts tomorrow" : "Beginnt morgen",
    "Started on" : "Begonnen am",
    "Starts on" : "Beginnt am",
    "[Remind me yesterday at ]HH:mm" : "[Mich gestern erinnert um ]HH:mm",
    "[Remind me today at ]HH:mm" : "[Erinnere mich heute um ]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[Erinnere mich morgen um ]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Erinnere mich am ]MMM DD, YYYY,[ um ]HH:mm",
    "Yesterday" : "Gestern",
    "Today" : "Heute",
    "Tomorrow" : "Morgen",
    "in %s" : "in %s",
    "%s ago" : "vor %s",
    "seconds" : "Sekunden",
    "a minute" : "Eine Minute",
    "%d minutes" : "%d Minuten",
    "an hour" : "Eine Stunde",
    "%d hours" : "%d Stunden",
    "a day" : "Ein Tag",
    "%d days" : "%d Tage",
    "a month" : "Ein Monat",
    "%d months" : "%d Monate",
    "a year" : "Ein Jahr",
    "%d years" : "%d Jahre",
    "week" : "Woche",
    "weeks" : "Wochen",
    "day" : "Tag",
    "days" : "Tage",
    "hour" : "Stunde",
    "hours" : "Stunden",
    "minute" : "Minute",
    "minutes" : "Minuten",
    "second" : "Sekunde",
    "before beginning" : "Vor Beginn",
    "after beginning" : "Nach Beginn",
    "before end" : "Vor Ende",
    "after end" : "Nach Ende",
    "Comment" : "Kommentar",
    "Add a comment" : "Einen Kommentar hinzufügen",
    "This will delete the Calendar \"%s\" and all of its entries." : "Dadurch werden der Kalender „%s“ und alle seine Einträge gelöscht.",
    "The name \"%s\" is already used." : "Der Name „%s“ wird bereits verwendet.",
    "An empty name is not allowed." : "Ein leerer Name ist nicht erlaubt.",
    "Hidden" : "Verborgen",
    "Visible" : "Sichtbar",
    "Automatic" : "Automatisch",
    "Sunday" : "Sonntag",
    "Monday" : "Montag",
    "Tuesday" : "Dienstag",
    "Wednesday" : "Mittwoch",
    "Thursday" : "Donnerstag",
    "Friday" : "Freitag",
    "Saturday" : "Samstag",
    "Add an important item in \"%s\"..." : "Einen wichtigen Eintrag in „%s“ hinzufügen…",
    "Add an item due today in \"%s\"..." : "Einen heute fälligen Eintrag in „%s“ hinzufügen…",
    "Add an item in \"%s\"..." : "Einen Eintrag in „%s“ hinzufügen…",
    "Add a current item in \"%s\"..." : "Einen aktuellen Eintrag in „%s“ hinzufügen…",
    "Add a subtask to \"%s\"..." : "Füge eine Unteraufgabe zu \"%s\" hinzu…",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n erledigte Aufgabe","%n erledigte Aufgaben"],
    "Hours" : "Stunden",
    "Minutes" : "Minuten",
    "Set due date" : "Ablaufdatum setzen",
    "%s %% completed" : "%s %% fertiggestellt",
    "priority %s: " : "Priorität %s:",
    "high" : "hoch",
    "medium" : "mittel",
    "low" : "niedrig",
    "no priority assigned" : "keine Priorität zugewiesen",
    "Remind me" : "Erinnere mich",
    "at the end" : "am Ende",
    "at the beginning" : "bei Beginn",
    "Set start date" : "Startdatum setzen",
    "{calendar} shared by {owner}" : "{calendar} geteilt von {owner}",
    "Unnamed" : "Unbenannt",
    "Important" : "Wichtig",
    "Week" : "Woche",
    "All" : "Alle",
    "Current" : "Aktuell",
    "Completed" : "Fertiggestellt",
    "Delete" : "Löschen",
    "Cancel" : "Abbrechen",
    "Edit" : "Bearbeiten",
    "Link" : "Link",
    "Download" : "Herunterladen",
    "Save" : "Speichern",
    "Add List..." : "Liste hinzufügen…",
    "New List" : "Neue Liste",
    "Settings" : "Einstellungen",
    "Start of week" : "Erster Wochentag",
    "Visibility of Smart Collections" : "Sichtbarkeit der intelligenten Sammlungen",
    "Change sort order" : "Sortierreihenfolge ändern",
    "Default" : "Standard",
    "Due date" : "Fälligkeitsdatum",
    "Start date" : "Startdatum",
    "Priority" : "Priorität",
    "Alphabetically" : "Alphabetisch",
    "Manually" : "Manuell",
    "Load remaining completed tasks." : "Die restlichen abgeschlossenen Aufgaben laden.",
    "Task is completed" : "Aufgabe fertiggestellt",
    "All day" : "Ganztägig",
    "(New category)" : "(Neue Kategorie)",
    "Select categories..." : "Kategorien auswählen…",
    "Loading the task..." : "Laden der Aufgabe…",
    "Task not found!" : "Aufgabe nicht gefunden!",
    "add a subtask to" : "Füge eine Teilaufgabe hinzu",
    "Toggle subtasks" : "Unteraufgaben umschalten",
    "Toggle completed subtasks" : "Fertige Unteraufgaben umschalten"
},
"nplurals=2; plural=(n != 1);");
